@@ -141,9 +141,9 @@ function renderModule(data, moduleName, expanded) {
               ),
               el('span', {
                 'class': 'route-name' + (route.name ? '' : ' unnamed-item')
-              }, route.name || '<未命名>'),
-              el('span', {'class': 'comment', html: true}, route.handler_info.description)
+              }, route.name || '<未命名>')
             ]),
+            el('p', {'class': 'comment route-description', html: true}, route.handler_info.description),
             el('div', {
               'class': 'url-info'
             }, [
@@ -206,7 +206,7 @@ function getArgValueString(value, editable) {
     return value ? 'true' : 'false'
   }
 
-  if (typeof value === 'string') {
+  if (!editable && typeof value === 'string') {
     return '"' + value + '"'
   }
 
@@ -218,7 +218,7 @@ function getArgDefaultValue(arg, editable) {
 
   // 将元组和列表视作同种类型
   // 事实上，后台已经处理过这个类型，此处并不会接收到 tuple 类型
-  if (arg.annotation_name !== 'list') {
+  if (arg.annotation_name !== 'list' || defaultValue === null) {
     return getArgValueString(defaultValue, editable)
   }
 
@@ -281,6 +281,8 @@ function renderArg(arg, editable) {
       argType = 'string'
     } else if (argType === 'HttpFile') {
       argType = 'file'
+    } else if (argType === 'list') {
+      argType = 'array'
     }
   } else {
     argType = '-'
@@ -295,7 +297,9 @@ function renderArg(arg, editable) {
       null,
       el(
         arg.has_annotation ? 'code' : 'span',
-        null,
+        {
+          'class': 'arg-type' + (arg.is_variable ? ' is-variable' : '')
+        },
         argType
       )
     ),
