@@ -15,9 +15,10 @@ class ApiPage:
         self.api_page_html_cache = ''
 
     def dispatch(self, request):
-        if not self.context.api_page_enabled:
-            self.context.logger.info(
-                'API list is disabled, '
+        if not self.context.api_page_options['api_page_enabled']:
+            from ..util import Logger
+            Logger.get(self.context.app_id).info(
+                'API page is disabled, '
                 'use "App(..., api_page_enabled=True, ...)" to enable it.')
             return HttpResponse(status=404)
 
@@ -32,9 +33,10 @@ class ApiPage:
         return HttpResponse(status=405)
 
     def do_get(self):
-        if not self.api_page_html_cache or not self.context.api_page_options['api_page_cache']:
+        api_page_options = self.context.api_page_options
+        if not self.api_page_html_cache or not api_page_options['api_page_cache']:
             with open(os.path.join(os.path.dirname(__file__),
-                                   '../internal_assets/templates/apipage.html'),
+                                   '../internal_assets/templates/api_page.html'),
                       encoding='utf-8') as fp:
                 lines = fp.readlines()
                 self.api_page_html_cache = ''.join(lines)
@@ -42,9 +44,11 @@ class ApiPage:
         return HttpResponse(self.api_page_html_cache, content_type='text/html')
 
     def do_post(self):
-        if not self.routes_cache or not self.context.api_page_options['api_page_cache']:
-            routes = self.context.collector.collect(self.context.routes_map)
-            addition_func = self.context.api_page_options.get('api_page_addition')
+        api_page_options = self.context.api_page_options
+        if not self.routes_cache or not api_page_options['api_page_cache']:
+            from . import Collector
+            routes = Collector.get(self.context.app_id).collect(self.context.routes_map)
+            addition_func = api_page_options.get('api_page_addition')
 
             for route in routes:
                 # 附加信息
@@ -83,8 +87,8 @@ class ApiPage:
                 'version': __meta__.version,
                 'url': __meta__.website
             },
-            'name': self.context.api_page_options['api_page_name'],
-            'expanded': self.context.api_page_options['api_page_expanded'],
+            'name': api_page_options['api_page_name'],
+            'expanded': api_page_options['api_page_expanded'],
             'routes': self.routes_cache,
         }, encoder=FunctionDescription.JSONEncoder)
 
